==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/syncsubtitlesdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "syncsubtitlesdialog.h"

#include <qgroupbox.h>
#include <qradiobutton.h>
#include <qlayout.h>

#include <klocale.h>


using namespace SubtitleComposer;

SyncSubtitlesDialog::SyncSubtitlesDialog( const QString& defaultEncoding, QWidget* parent ):
	SelectableSubtitleDialog( defaultEncoding, i18n( "Synchronize With Subtitle" ), parent )
{
	createSubtitleGroupBox( i18n( "Reference subtitle" ) );

	QGroupBox* syncModeGroup = createGroupBox( i18n( "Synchronization mode" ));

	m_adjustRadioButton = new QRadioButton( syncModeGroup );
	m_adjustRadioButton->setText( i18n( "Adjust to reference subtitle first and last lines' times" ) );
	m_adjustRadioButton->setChecked( true );

	m_synchronizeRadioButton = new QRadioButton( syncModeGroup );
	m_synchronizeRadioButton->setText( i18n( "Copy timing information from reference subtitle line by line" ) );

	QGridLayout* syncModeLayout = createLayout( syncModeGroup );
	syncModeLayout->addWidget( m_adjustRadioButton, 0, 0 );
	syncModeLayout->addWidget( m_synchronizeRadioButton, 1, 0 );
}

bool SyncSubtitlesDialog::adjustToReferenceSubtitle()
{
	return m_adjustRadioButton->isChecked();
}

bool SyncSubtitlesDialog::synchronizeToReferenceTimes()
{
	return m_synchronizeRadioButton->isChecked();
}

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/main/dialogs/syncsubtitlesdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "syncsubtitlesdialog.h"

#include <qbuttongroup.h>
#include <qradiobutton.h>
#include <qlayout.h>

#include <klocale.h>


using namespace SubtitleComposer;

SyncSubtitlesDialog::SyncSubtitlesDialog( const QString& defaultEncoding, QWidget* parent ):
	SelectableSubtitleDialog( defaultEncoding, i18n( "Synchronize With Subtitle" ), parent )
{
	createSubtitleButtonGroup( i18n( "Reference subtitle" ) );

	QButtonGroup* syncModeGroup = createButtonGroup( i18n( "Synchronization mode" ));

	m_adjustRadioButton = new QRadioButton( syncModeGroup );
	m_adjustRadioButton->setText( i18n( "Adjust to reference subtitle first and last lines' times" ) );
	m_adjustRadioButton->setChecked( true );

	m_synchronizeRadioButton = new QRadioButton( syncModeGroup );
	m_synchronizeRadioButton->setText( i18n( "Copy timing information from reference subtitle line by line" ) );

	QGridLayout* syncModeLayout = createLayout( syncModeGroup );
	syncModeLayout->addWidget( m_adjustRadioButton, 0, 0 );
	syncModeLayout->addWidget( m_synchronizeRadioButton, 1, 0 );
}

bool SyncSubtitlesDialog::adjustToReferenceSubtitle() const
{
	return m_adjustRadioButton->isChecked();
}

bool SyncSubtitlesDialog::synchronizeToReferenceTimes() const
{
	return m_synchronizeRadioButton->isChecked();
}
